@@ -2,6 +2,9 @@
 {
 # Image
 'N_X' : 256, # size of images
+'N_Y' : 256, # size of images
+'do_whitening'  : True, # = self.pe.do_whitening
+'do_mask'  : True, # self.pe.do_mask
 # Log-Gabor
 #'base_levels' : 2.,
 'base_levels' : 1.618,
@@ -9,6 +12,9 @@
 'B_sf' : 1.5, # 1.5 in Geisler
 'B_theta' : 3.14159/8.,
 'figpath' : 'figures/',
+'edgefigpath' : 'figures/edges/',
+'matpath' : 'mat/',
+'edgematpath' : 'mat/edges/',
 'datapath' : 'database/',
 'ext' : '.pdf',
 # EdgeFactory PARAMETERS
